@@ -247,12 +247,14 @@ class LanguagesPopup(Gtk.Window):
     def do_button_press_event(self, event):
         if not self.in_window(event):
             self.destroy()
+            return True
         else:
             return self.propagate_mouse_event(event)
 
     def do_button_release_event(self, event):
         if not self.in_window(event):
             self.destroy()
+            return True
         else:
             return self.propagate_mouse_event(event)
 
@@ -286,17 +288,22 @@ class Manager(GObject.Object):
         GObject.Object.__init__(self)
         self.datadir = datadir
         self.dialog = None
+        self._size = (0, 0)
         self._languages = {}
         self._tool_rows = {}
 
         self.build()
 
+    def get_final_size(self):
+        return self._size
+
     def build(self):
         callbacks = {
             'on_action_add_tool_activated'    : self.on_action_add_tool_activated,
             'on_action_remove_tool_activated' : self.on_action_remove_tool_activated,
             'on_tool_manager_dialog_response' : self.on_tool_manager_dialog_response,
             'on_tool_manager_dialog_focus_out': self.on_tool_manager_dialog_focus_out,
+            'on_tool_manager_dialog_configure_event': self.on_tool_manager_dialog_configure_event,
             'on_accelerator_key_press'        : self.on_accelerator_key_press,
             'on_accelerator_focus_in'         : self.on_accelerator_focus_in,
             'on_accelerator_focus_out'        : self.on_accelerator_focus_out,
@@ -880,6 +887,11 @@ class Manager(GObject.Object):
         self.save_current_tool()
         self.emit('tools-updated')
 
+    def on_tool_manager_dialog_configure_event(self, dialog, event):
+        if dialog.get_realized():
+            alloc = dialog.get_allocation()
+            self._size = (alloc.width, alloc.height)
+
     def get_cell_data_cb(self, column, cell, model, piter, user_data=None):
         tool = model.get_value(piter, self.TOOL_COLUMN)
 
